@@ -1,6 +1,6 @@
 from .decorators import TestCaseDecorator
 from .metaclasses import TestCaseMeta
-from pip._vendor import six
+import six
 
 
 __all__ = ['WrapCasesMixin', 'wrap_case']
